@@ -13,6 +13,11 @@ sub new {
 sub type      { $_[0]->{type}      }
 sub mode      { $_[0]->{mode}      }
 sub timestamp { $_[0]->{timestamp} }
+sub webhook_event_id { $_[0]->{webhookEventId} }
+
+# Whether the webhook event is a redelivered one or not. 
+# https://developers.line.biz/en/docs/messaging-api/receiving-messages/#redelivered-webhooks
+sub is_redelivery { $_[0]->{deliveryContext}{isRedelivery} }
 
 # Unfollow and Leave events don't have this
 sub reply_token { $_[0]->{replyToken} }
@@ -30,6 +35,9 @@ sub is_beacon_detection_event { 0 }
 sub is_device_link_event      { 0 }
 sub is_device_unlink_event    { 0 }
 sub is_account_link_event     { 0 }
+sub is_unsend_event { 0 }
+sub is_video_viewing_complete_event { 0 }
+sub is_unknown_event { 0 }
 
 # source field
 sub is_user_event  { $_[0]->{source}{type} eq 'user' }
